This function is geared towards replicating and extending the statistical power analysis
from Table 3 cell block 2.1 of the paper by Dwivedi et al. (2017). It deals with
scenarios involving skewed distributions with equal variance and different means
in the two groups. It acts as a wrapper around replext_t2_c1.1, with specific
adjustments for skewness parameters and means.
replext_t3_c2.1(
M1 = 5,
S1 = 1,
M2 = 7,
S2 = 1,
Sk1 = 0.8,
Sk2 = 0.8,
n1 = c(3, 4, 5, 6, 7, 8, 9, 10, 15, 25, 50, 100),
n2 = c(3, 4, 5, 6, 7, 8, 9, 10, 15, 25, 50, 100),
n_simulations = 10000,
nboot = 1000,
conf.level = 0.95
)A data frame with columns for each sample size pair (n1, n2) and the proportions of significant p-values for each test (ST, WT, NPBTT, WRST, PTT), reflecting the power analysis.
Mean for the first group, default is 5.
Standard deviation for the first group, default is 1.
Mean for the second group, default is 7.
Standard deviation for the second group, default is 1.
Skewness parameter for the first group, default is 0.8.
Skewness parameter for the second group, default is 0.8.
Vector of sample sizes for the first group.
Vector of sample sizes for the second group, must be the same length as n1.
Number of simulations to run, default is 10,000.
Number of bootstrap samples, default is 1000.
Confidence level for calculating p-value thresholds, default is 0.95.
Dwivedi AK, Mallawaarachchi I, Alvarado LA. Analysis of small sample size studies using nonparametric bootstrap test with pooled resampling method. Stat Med. 2017 Jun 30;36(14):2187-2205. doi: 10.1002/sim.7263. Epub 2017 Mar 9. PMID: 28276584.
replext_t2_c1.1
replext_t3_c2.1(n1 = c(10), n2 = c(10), n_simulations = 1)
Run the code above in your browser using DataLab