Learn R Programming

npboottprm (version 0.3.2)

replext_t4_c1.1: Replicate and Extend Simulation Results from Table 4 Cell 1.1

Description

This function aims to replicate and extend the simulation results from Table 4 cell 1.1 of the paper by Dwivedi et al. (2017). The default parameters are set to replicate the results for the lognormal distribution scenarios as presented in the paper, while modifying the parameter values allows for an extension of these results.

Usage

replext_t4_c1.1(
  rdist = "rlnorm",
  par1_1 = 1,
  par2_1 = 0.6,
  par1_2 = 2,
  par2_2 = 1,
  n1 = c(5, 5, 10),
  n2 = c(5, 10, 10),
  n_simulations = 10000,
  nboot = 1000,
  conf.level = 0.95
)

Value

A data frame with columns for each sample size pair (n1, n2) and the proportions of significant p-values for each test (ST, WT, NPBTT, WRST, PTTa, PTTe).

Arguments

rdist

Distribution type, default is 'rlnorm' (lognormal). Other options are 'rpois' (Poisson), 'rchisq' (Chi-squared), and 'rcauchy' (Cauchy).

par1_1

First parameter for the first group's distribution, default is 1.

par2_1

Second parameter for the first group's distribution, default is 0.6.

par1_2

First parameter for the second group's distribution, default is 2.

par2_2

Second parameter for the second group's distribution, default is 1.

n1

Vector of sample sizes for the first group.

n2

Vector of sample sizes for the second group, must be the same length as n1.

n_simulations

Number of simulations to run, default is 10,000.

nboot

Number of bootstrap samples, default is 1000.

conf.level

Confidence level for calculating p-value thresholds, default is 0.95.

References

Dwivedi AK, Mallawaarachchi I, Alvarado LA. Analysis of small sample size studies using nonparametric bootstrap test with pooled resampling method. Stat Med. 2017 Jun 30;36(14):2187-2205. doi: 10.1002/sim.7263. Epub 2017 Mar 9. PMID: 28276584.

Examples

Run this code
replext_t4_c1.1(n1 = c(10), n2 = c(10),n_simulations = 1)

Run the code above in your browser using DataLab