This function is a specialized wrapper around 'replext_t4_c1.1', tailored to replicate and extend the simulation results from Table 4 cell 4.1 of the paper by Dwivedi et al. (2017). It sets the default parameters to correspond with the lognormal distribution scenarios for this specific cell, allowing for both replication and extension of the results.
replext_t4_c4.1(
rdist = "rlnorm",
par1_1 = 1,
par2_1 = 0.6,
par1_2 = 3,
par2_2 = 4,
n1 = c(5, 5, 10),
n2 = c(5, 10, 10),
n_simulations = 10000,
nboot = 1000,
conf.level = 0.95
)A data frame with columns for each sample size pair (n1, n2) and the proportions of significant p-values for each test (ST, WT, NPBTT, WRST, PTTa, PTTe).
Distribution type, with the default set to 'rlnorm' (lognormal). Other options include 'rpois' (Poisson), 'rchisq' (Chi-squared), and 'rcauchy' (Cauchy).
First parameter (meanlog) for the first group's distribution, default is 1.
Second parameter (sdlog) for the first group's distribution, default is 0.6.
First parameter (meanlog) for the second group's distribution, default is 3.
Second parameter (sdlog) for the second group's distribution, default is 4.
Vector of sample sizes for the first group.
Vector of sample sizes for the second group, must be the same length as n1.
Number of simulations to run, default is 10,000.
Number of bootstrap samples, default is 1000.
Confidence level for calculating p-value thresholds, default is 0.95.
Dwivedi AK, Mallawaarachchi I, Alvarado LA. Analysis of small sample size studies using nonparametric bootstrap test with pooled resampling method. Stat Med. 2017 Jun 30;36(14):2187-2205. doi: 10.1002/sim.7263. Epub 2017 Mar 9. PMID: 28276584.
replext_t4_c4.1(n1 = c(10), n2 = c(10), n_simulations = 1)
Run the code above in your browser using DataLab