This function is a wrapper around replext_ts2_c1.1. The function is designed
to reproduce or extend the statistical power analysis for ANOVA (Analysis of
Variance) from Dwivedi et al. (2017) supplemental table 3, cell 2.2.
replext_ts3_c2.2(
M1 = 5,
S1 = 1,
M2 = 6,
S2 = 2,
M3 = 7,
S3 = 4,
Sk1 = 0.8,
Sk2 = 0.8,
Sk3 = 0.8,
n1 = c(2, 3, 4, 5, 6, 7, 8, 9, 10, 15, 25, 50, 100),
n2 = c(2, 3, 4, 5, 6, 7, 8, 9, 10, 15, 25, 50, 100),
n3 = c(2, 3, 4, 5, 6, 7, 8, 9, 10, 15, 25, 50, 100),
n_simulations = 10000,
nboot = 1000,
conf.level = 0.95
)A data frame with columns for each sample size combination (n1, n2, n3) and the proportions of significant p-values for each test (ANOVA, Kruskal-Wallis, Nonparametric Bootstrap F-test, Permutation F-test).
Mean for the first group, default is 5.
Standard deviation for the first group, default is 1.
Mean for the second group, default is 6.
Standard deviation for the second group, default is 2.
Mean for the third group, default is 7.
Standard deviation for the third group, default is 4.
Skewness parameter for the first group, default is 0.8.
Skewness parameter for the second group, default is 0.8.
Skewness parameter for the third group, default is 0.8.
Vector of sample sizes for the first group.
Vector of sample sizes for the second group.
Vector of sample sizes for the third group, must be the same length as n1 and n2.
Number of simulations to run, default is 10,000.
Number of bootstrap samples for the nonparametric bootstrap test, default is 1000.
Confidence level for calculating p-value thresholds, default is 0.95.
Dwivedi AK, Mallawaarachchi I, Alvarado LA. Analysis of small sample size studies using nonparametric bootstrap test with pooled resampling method. Stat Med. 2017 Jun 30;36(14):2187-2205. doi: 10.1002/sim.7263. Epub 2017 Mar 9. PMID: 28276584.
replext_ts2_c1.1
replext_ts3_c2.2(n1 = c(10), n2 = c(10), n3 = c(10), n_simulations = 1)
Run the code above in your browser using DataLab